{% extends "socialschools_cms/base.html" %}
{% load cms_tags %}
{% load menu_tags %}

{% block wrapper%}
    <div class="row-fluid">
        <div class="span9">
            <div class="css-content-white main-content">
            {% show_breadcrumb "socialschools_cms/menu/breadcrumb.html" %}
                <div class="row-fluid">
                    <div class="span4">
                        <ul class="nav nav-tabs nav-stacked">
                        {% show_menu 1 100 0 100 "socialschools_cms/menu/menu.html" %}
                        </ul>
                    </div>
                    <div class="span8">
                        {% placeholder content_block_1 %}
                    </div>
                </div>
            </div>
        </div>
        <div class="span3">
            <div class="css-content-white">
                {% placeholder widget_block_1 %}
            </div>
        </div>
    </div>

{% endblock %}

