{% extends "socialschools_cms/base.html" %}
{% load cms_tags %}
{% load socialschools_tags %}

{% block wrapper%}
    <div class="row-fluid">
        <div class="span8">
            <div class="css-content-white main-content">
                <div class="row-fluid">
                    <div class="span6">
                        {% placeholder welcome_block_left %}
                    </div>
                    <div class="span6">
                        {% placeholder welcome_block_right %}
                    </div>
                </div>
                <div class="well css-well">
                    {% include "socialschools_cms/news.html" %}
                </div>
            </div>
        </div>
        <div class="span4">
            {% socialschools_login %}
            <div class="css-content-white content-block widget-1">
                {% placeholder widget_block_1 %}
            </div>
            <div class="css-content-white content-block widget-2">
                {% placeholder widget_block_2 %}
            </div>
        </div>
    </div>

{% endblock %}

