{% load staticfiles %}
{% load sekizai_tags %}
{% load menu_tags %}
{% load i18n %}

<!DOCTYPE html>
<html>
    <head>
        <meta charset="utf-8">
        <meta http-equiv="X-UA-Compatible" content="IE=edge,chrome=1">
        <meta name="csrf-token" content="{{csrf_token}}">

        <title>{% block _title %}{% endblock %}</title>

        <meta name="description" content="{% block _description %}{% endblock %}">
        <meta name="keywords" content="{% block _keywords %}{% endblock %}">
        <meta name="author" content="Changer">

        {% if debug %}
            <link rel="stylesheet/less" type="text/css" href="{% static 'socialschools_cms/css/styles.less' %}">
            <script src="{% static 'socialschools/js/less.1.3.3.min.js' %}"></script>
        {% else %}
            <link rel="stylesheet" type="text/css" href="{% static 'socialschools_cms/css/styles.css' %}">
        {% endif %}

        {% render_block 'css' %}
    </head>
    <body>
        <div class="wrapper">
            <div class="navbar navbar-fixed-top">
                <div class="navbar-inner">
                    <div class="container">
                    {% block navbar%}
                    <ul class="nav">
                        {% show_menu 0 0 0 100 "socialschools_cms/menu/menu.html" %}
                    </ul>
                    {% endblock %}
                    </div>
                </div>
            </div>
            <div class="container">
                <div class="footer-spacer-top">
                    {% block wrapper %}
                    {% endblock %}
                </div>
            </div>
            <div class="footer-spacer">
            </div>
        </div>

        <footer class="footer">
            {% block footer %}
            <div class="container">
                {% show_menu 0 1 1 100 "socialschools_cms/footer.html" %}
            </div>
            {% endblock %}
        </footer>
        {% block js %}
        {% endblock %}
        {% render_block 'js' %}

        <!-- modal-gallery is the modal dialog used for the image gallery -->
        <div id="modal-gallery" class="modal modal-gallery hide fade" tabindex="-1">
            <div class="modal-header">
                <a class="close" data-dismiss="modal">&times;</a>
                <h3 class="modal-title"></h3>
            </div>
            <div class="modal-body"><div class="modal-image"></div></div>
            <div class="modal-footer">
                <a class="btn btn-primary modal-prev"><i class="icon-arrow-left icon-white"></i>{% trans 'Previous' %}</a>
                <a class="btn btn-primary modal-next">{% trans 'Next' %} <i class="icon-arrow-right icon-white"></i></a>
                <a class="btn modal-play modal-slideshow" data-slideshow="5000"><i class="icon-play"></i> {% trans 'Slideshow' %}</a>
                <a class="btn modal-download" target="_blank"><i class="icon-download"></i> {% trans 'Download' %}</a>
            </div>
        </div>

    </body>
</html>

{% addtoblock "js" %}
<script type="text/javascript" src="{% static 'socialschools_cms/js/jquery.1.9.1.min.js' %}"></script>
<script type="text/javascript" src="{% static 'socialschools_cms/js/bootstrap.min.js' %}"></script>
{% endaddtoblock %}
